@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 import inspect
 import sys
 
@@ -7,6 +9,12 @@ from _pytest_mock_version import version
 
 __version__ = version
 
+# pseudo-six; if this starts to require more than this, depend on six already
+if sys.version_info[0] == 2:  # pragma: no cover
+    text_type = unicode  # noqa
+else:
+    text_type = str
+
 
 def _get_mock_module(config):
     """
@@ -40,10 +48,12 @@ class MockFixture(object):
         # aliases for convenience
         self.Mock = mock_module.Mock
         self.MagicMock = mock_module.MagicMock
+        self.NonCallableMock = mock_module.NonCallableMock
         self.PropertyMock = mock_module.PropertyMock
         self.call = mock_module.call
         self.ANY = mock_module.ANY
         self.DEFAULT = mock_module.DEFAULT
+        self.create_autospec = mock_module.create_autospec
         self.sentinel = mock_module.sentinel
         self.mock_open = mock_module.mock_open
 
@@ -179,21 +189,21 @@ def assert_wrapper(__wrapped_mock_method__, *args, **kwargs):
         return
     except AssertionError as e:
         if getattr(e, '_mock_introspection_applied', 0):
-            msg = str(e)
+            msg = text_type(e)
         else:
             __mock_self = args[0]
-            msg = str(e)
+            msg = text_type(e)
             if __mock_self.call_args is not None:
                 actual_args, actual_kwargs = __mock_self.call_args
                 msg += '\n\npytest introspection follows:\n'
                 try:
                     assert actual_args == args[1:]
                 except AssertionError as e:
-                    msg += '\nArgs:\n' + str(e)
+                    msg += '\nArgs:\n' + text_type(e)
                 try:
                     assert actual_kwargs == kwargs
                 except AssertionError as e:
-                    msg += '\nKwargs:\n' + str(e)
+                    msg += '\nKwargs:\n' + text_type(e)
     e = AssertionError(msg)
     e._mock_introspection_applied = True
     raise e
